Kontakt na výrobce HS Flamingo s.r.o.
Author: HS Flamingo s.r.o
Keywords: krbová kamna vložky kouřovody biokrby

Přeskočit na hlavní obsah / Přeskočit na doplňující obsah

X
Produkt byl přidán do objednávky.

Objednávky +420 491 422 647

Váš košík je prázdný

Přihlášení zákazníka

Přihlašovací jméno:

Vaše heslo:

Zapomněli jste heslo?

Úvod Kontakt

# Kontakt

## Sídlo společnosti:

HS Flamingo s.r.o.
třída Osvobození 65, CZ - 550 01 Broumov
IČO: 27488683, DIČ: CZ27488683

Obchodní rejstřík Krajského soudu v Hradci Králové oddíl C vložka 22006

## Telefonní spojení:

Obchodní oddělení tuzemsko: | +420 491 422 647
Obchodní oddělení Slovensko: | +421 414 214 558
Obchodní oddělení export: | +420 491 615 680 / +420 731 616 756
Technické oddělení: | +420 491 615 681
Fax: | +420 491 521 140

## Emailové spojení:

Obchodní oddělení tuzemsko: | info@hsflamingo.cz
Obchodní oddělení Slovensko: | info@hsflamingo.sk
Obchodní oddělení export: | export@hsflamingo.cz
Technické oddělení: | podpora@hsflamingo.cz
Reklamace: | reklamace@hsflamingo.cz
Účetní oddělení: | ucetni@hsflamingo.cz

## Zaměstnání v HS Flamingo:

> Dlouhodobě obsazované pozice

## Bankovní spojení:

/CZK/
43-7314850237/0100 Komerční banka a.s.
IBAN: CZ5301 0000 0043 7314 8502 37
SWIFT: KOMBCZPP

/EUR/
43-7316110267/0100 Komerční banka a.s.
IBAN: CZ5301 0000 0043 7316 1102 67
SWIFT: KOMBCZPP

## Napište nám

Vaše jméno a příjmení:*

Váš e-mail:*

Vaše zpráva pro nás:*

Položky označené hvězdičkou (*) jsou povinné.

Po kliknutí na "Odeslat zprávu", bude zpráva zaslána na náš e-mail. Odpověď můžete očekávat do 2 pracovních dnů. Většinou to ale bývá do pár hodin.

Vytisknout stránku

## Doplňující obsah

Přeskočit na začátek stránky

© 2015, HS Flamingo s.r.o. – všechna práva vyhrazena

Prohlášení o přístupnosti | Mapa stránek

Webové stránky vytvořila eBRÁNA s.r.o. | E-shop vytvořen na Profesionální CMS | Výměna odkazů | XHTML 1.0

Tento eshop používá k poskytování služeb, personalizaci reklam a analýze návštěvnosti soubory cookie. Používáním tohoto webu s tím souhlasíte. Více informací Rozumím